@@ -4,6 +4,7 @@
 #'
 #' @param model A \pkg{lavaan} model.
 #' @param metrics Can be \code{"all"} or a character vector of metrics to be computed (some of \code{c("Chisq", "Chisq_DoF", "Chisq_p", "Baseline", "Baseline_DoF", "Baseline_p", "CFI", "TLI", "NNFI", "RFI", "NFI", "PNFI", "IFI", "RNI", "Loglikelihood", "AIC", "BIC", "BIC_adjusted", "RMSEA", "SMRM")}).
+#' @param verbose Toggle off warnings.
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @return A data frame (with one row) and one column per "index" (see \code{metrics}).
@@ -44,21 +45,26 @@
 #' }
 #'
 #' @export
-model_performance.lavaan <- function(model, metrics = "all", ...) {
+model_performance.lavaan <- function(model, metrics = "all", verbose = TRUE, ...) {
   if (!requireNamespace("lavaan", quietly = TRUE)) {
     stop("Package `lavaan` needed for this function to work. Please install it.", call. = FALSE)
   }
 
-  measures <- as.data.frame(t(as.data.frame(lavaan::fitmeasures(model, ...))))
+  if (isTRUE(verbose)) {
+    measures <- as.data.frame(t(as.data.frame(lavaan::fitmeasures(model, ...))))
+  } else {
+    measures <- as.data.frame(t(as.data.frame(suppressWarnings(lavaan::fitmeasures(model, ...)))))
+  }
+
   row.names(measures) <- NULL
 
   out <- data.frame(
-    "Chisq" = measures$chisq,
-    "Chisq_df" = measures$df,
-    "Chisq_p" = measures$pvalue,
+    "Chi2" = measures$chisq,
+    "Chi2_df" = measures$df,
+    "p_Chi2" = measures$pvalue,
     "Baseline" = measures$baseline.chisq,
     "Baseline_df" = measures$baseline.df,
-    "Baseline_p" = measures$baseline.pvalue,
+    "p_Baseline" = measures$baseline.pvalue,
     "GFI" = measures$gfi,
     "AGFI" = measures$agfi,
     "NFI" = measures$nfi,
@@ -67,7 +73,7 @@ model_performance.lavaan <- function(model, metrics = "all", ...) {
     "RMSEA" = measures$rmsea,
     "RMSEA_CI_low" = measures$rmsea.ci.lower,
     "RMSEA_CI_high" = measures$rmsea.ci.upper,
-    "RMSEA_p" = measures$rmsea.pvalue,
+    "p_RMSEA" = measures$rmsea.pvalue,
     "RMR" = measures$rmr,
     "SRMR" = measures$srmr,
     "RFI" = measures$rfi,
@@ -83,6 +89,8 @@ model_performance.lavaan <- function(model, metrics = "all", ...) {
   if (all(metrics == "all")) {
     metrics <- names(out)
   }
+  out <- out[, metrics]
 
-  out[, metrics]
+  class(out) <- c("performance_lavaan", "performance_model", class(out))
+  out
 }
